# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/smartwebsecurity/v1/advanced_rate_limiter/advanced_rate_limiter_profile_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter import advanced_rate_limiter_profile_pb2 as yandex_dot_cloud_dot_smartwebsecurity_dot_v1_dot_advanced__rate__limiter_dot_advanced__rate__limiter__profile__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nbyandex/cloud/smartwebsecurity/v1/advanced_rate_limiter/advanced_rate_limiter_profile_service.proto\x12\x36yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1aZyandex/cloud/smartwebsecurity/v1/advanced_rate_limiter/advanced_rate_limiter_profile.proto\x1a\x1dyandex/cloud/validation.proto\"V\n$GetAdvancedRateLimiterProfileRequest\x12.\n advanced_rate_limiter_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"A\n&ListAdvancedRateLimiterProfilesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xa5\x01\n\'ListAdvancedRateLimiterProfilesResponse\x12z\n\x1e\x61\x64vanced_rate_limiter_profiles\x18\x01 \x03(\x0b\x32R.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterProfile\"\x87\x03\n\'CreateAdvancedRateLimiterProfileRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12{\n\x06labels\x18\x02 \x03(\x0b\x32k.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.CreateAdvancedRateLimiterProfileRequest.LabelsEntry\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12t\n\x1b\x61\x64vanced_rate_limiter_rules\x18\x05 \x03(\x0b\x32O.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"T\n(CreateAdvancedRateLimiterProfileMetadata\x12(\n advanced_rate_limiter_profile_id\x18\x01 \x01(\t\"\xcf\x03\n\'UpdateAdvancedRateLimiterProfileRequest\x12.\n advanced_rate_limiter_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12{\n\x06labels\x18\x03 \x03(\x0b\x32k.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.UpdateAdvancedRateLimiterProfileRequest.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12t\n\x1b\x61\x64vanced_rate_limiter_rules\x18\x06 \x03(\x0b\x32O.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"T\n(UpdateAdvancedRateLimiterProfileMetadata\x12(\n advanced_rate_limiter_profile_id\x18\x01 \x01(\t\"Y\n\'DeleteAdvancedRateLimiterProfileRequest\x12.\n advanced_rate_limiter_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"T\n(DeleteAdvancedRateLimiterProfileMetadata\x12(\n advanced_rate_limiter_profile_id\x18\x01 \x01(\t2\xc1\x0b\n!AdvancedRateLimiterProfileService\x12\x94\x02\n\x03Get\x12\\.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.GetAdvancedRateLimiterProfileRequest\x1aR.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterProfile\"[\x82\xd3\xe4\x93\x02U\x12S/smartwebsecurity/v1/advancedRateLimiterProfiles/{advanced_rate_limiter_profile_id}\x12\x81\x02\n\x04List\x12^.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.ListAdvancedRateLimiterProfilesRequest\x1a_.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.ListAdvancedRateLimiterProfilesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/smartwebsecurity/v1/advancedRateLimiterProfiles\x12\x94\x02\n\x06\x43reate\x12_.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.CreateAdvancedRateLimiterProfileRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*F\n(CreateAdvancedRateLimiterProfileMetadata\x12\x1a\x41\x64vancedRateLimiterProfile\x82\xd3\xe4\x93\x02\x35\"0/smartwebsecurity/v1/advancedRateLimiterProfiles:\x01*\x12\xb7\x02\n\x06Update\x12_.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.UpdateAdvancedRateLimiterProfileRequest\x1a!.yandex.cloud.operation.Operation\"\xa8\x01\xb2\xd2*F\n(UpdateAdvancedRateLimiterProfileMetadata\x12\x1a\x41\x64vancedRateLimiterProfile\x82\xd3\xe4\x93\x02X2S/smartwebsecurity/v1/advancedRateLimiterProfiles/{advanced_rate_limiter_profile_id}:\x01*\x12\xaf\x02\n\x06\x44\x65lete\x12_.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.DeleteAdvancedRateLimiterProfileRequest\x1a!.yandex.cloud.operation.Operation\"\xa0\x01\xb2\xd2*A\n(DeleteAdvancedRateLimiterProfileMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02U*S/smartwebsecurity/v1/advancedRateLimiterProfiles/{advanced_rate_limiter_profile_id}B\xa9\x01\n:yandex.cloud.api.smartwebsecurity.v1.advanced_rate_limiterZkgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/advanced_rate_limiter;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n:yandex.cloud.api.smartwebsecurity.v1.advanced_rate_limiterZkgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/advanced_rate_limiter;smartwebsecurity'
  _GETADVANCEDRATELIMITERPROFILEREQUEST.fields_by_name['advanced_rate_limiter_profile_id']._options = None
  _GETADVANCEDRATELIMITERPROFILEREQUEST.fields_by_name['advanced_rate_limiter_profile_id']._serialized_options = b'\350\3071\001'
  _LISTADVANCEDRATELIMITERPROFILESREQUEST.fields_by_name['folder_id']._options = None
  _LISTADVANCEDRATELIMITERPROFILESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATEADVANCEDRATELIMITERPROFILEREQUEST_LABELSENTRY._options = None
  _CREATEADVANCEDRATELIMITERPROFILEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEADVANCEDRATELIMITERPROFILEREQUEST.fields_by_name['folder_id']._options = None
  _CREATEADVANCEDRATELIMITERPROFILEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _UPDATEADVANCEDRATELIMITERPROFILEREQUEST_LABELSENTRY._options = None
  _UPDATEADVANCEDRATELIMITERPROFILEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEADVANCEDRATELIMITERPROFILEREQUEST.fields_by_name['advanced_rate_limiter_profile_id']._options = None
  _UPDATEADVANCEDRATELIMITERPROFILEREQUEST.fields_by_name['advanced_rate_limiter_profile_id']._serialized_options = b'\350\3071\001'
  _DELETEADVANCEDRATELIMITERPROFILEREQUEST.fields_by_name['advanced_rate_limiter_profile_id']._options = None
  _DELETEADVANCEDRATELIMITERPROFILEREQUEST.fields_by_name['advanced_rate_limiter_profile_id']._serialized_options = b'\350\3071\001'
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['Get']._options = None
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002U\022S/smartwebsecurity/v1/advancedRateLimiterProfiles/{advanced_rate_limiter_profile_id}'
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['List']._options = None
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0022\0220/smartwebsecurity/v1/advancedRateLimiterProfiles'
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['Create']._options = None
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*F\n(CreateAdvancedRateLimiterProfileMetadata\022\032AdvancedRateLimiterProfile\202\323\344\223\0025\"0/smartwebsecurity/v1/advancedRateLimiterProfiles:\001*'
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['Update']._options = None
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*F\n(UpdateAdvancedRateLimiterProfileMetadata\022\032AdvancedRateLimiterProfile\202\323\344\223\002X2S/smartwebsecurity/v1/advancedRateLimiterProfiles/{advanced_rate_limiter_profile_id}:\001*'
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['Delete']._options = None
  _ADVANCEDRATELIMITERPROFILESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*A\n(DeleteAdvancedRateLimiterProfileMetadata\022\025google.protobuf.Empty\202\323\344\223\002U*S/smartwebsecurity/v1/advancedRateLimiterProfiles/{advanced_rate_limiter_profile_id}'
  _globals['_GETADVANCEDRATELIMITERPROFILEREQUEST']._serialized_start=419
  _globals['_GETADVANCEDRATELIMITERPROFILEREQUEST']._serialized_end=505
  _globals['_LISTADVANCEDRATELIMITERPROFILESREQUEST']._serialized_start=507
  _globals['_LISTADVANCEDRATELIMITERPROFILESREQUEST']._serialized_end=572
  _globals['_LISTADVANCEDRATELIMITERPROFILESRESPONSE']._serialized_start=575
  _globals['_LISTADVANCEDRATELIMITERPROFILESRESPONSE']._serialized_end=740
  _globals['_CREATEADVANCEDRATELIMITERPROFILEREQUEST']._serialized_start=743
  _globals['_CREATEADVANCEDRATELIMITERPROFILEREQUEST']._serialized_end=1134
  _globals['_CREATEADVANCEDRATELIMITERPROFILEREQUEST_LABELSENTRY']._serialized_start=1089
  _globals['_CREATEADVANCEDRATELIMITERPROFILEREQUEST_LABELSENTRY']._serialized_end=1134
  _globals['_CREATEADVANCEDRATELIMITERPROFILEMETADATA']._serialized_start=1136
  _globals['_CREATEADVANCEDRATELIMITERPROFILEMETADATA']._serialized_end=1220
  _globals['_UPDATEADVANCEDRATELIMITERPROFILEREQUEST']._serialized_start=1223
  _globals['_UPDATEADVANCEDRATELIMITERPROFILEREQUEST']._serialized_end=1686
  _globals['_UPDATEADVANCEDRATELIMITERPROFILEREQUEST_LABELSENTRY']._serialized_start=1089
  _globals['_UPDATEADVANCEDRATELIMITERPROFILEREQUEST_LABELSENTRY']._serialized_end=1134
  _globals['_UPDATEADVANCEDRATELIMITERPROFILEMETADATA']._serialized_start=1688
  _globals['_UPDATEADVANCEDRATELIMITERPROFILEMETADATA']._serialized_end=1772
  _globals['_DELETEADVANCEDRATELIMITERPROFILEREQUEST']._serialized_start=1774
  _globals['_DELETEADVANCEDRATELIMITERPROFILEREQUEST']._serialized_end=1863
  _globals['_DELETEADVANCEDRATELIMITERPROFILEMETADATA']._serialized_start=1865
  _globals['_DELETEADVANCEDRATELIMITERPROFILEMETADATA']._serialized_end=1949
  _globals['_ADVANCEDRATELIMITERPROFILESERVICE']._serialized_start=1952
  _globals['_ADVANCEDRATELIMITERPROFILESERVICE']._serialized_end=3425
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.assistants.v1.users.user_pb2
import yandex.cloud.ai.common.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    source: builtins.str
    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        source: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiration_config", b"expiration_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "expiration_config", b"expiration_config", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "source", b"source"]) -> None: ...

global___CreateUserRequest = CreateUserRequest

@typing.final
class GetUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___GetUserRequest = GetUserRequest

@typing.final
class UpdateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    USER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiration_config", b"expiration_config", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "expiration_config", b"expiration_config", "labels", b"labels", "name", b"name", "update_mask", b"update_mask", "user_id", b"user_id"]) -> None: ...

global___UpdateUserRequest = UpdateUserRequest

@typing.final
class DeleteUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___DeleteUserRequest = DeleteUserRequest

@typing.final
class DeleteUserResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteUserResponse = DeleteUserResponse

@typing.final
class ListUsersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListUsersRequest = ListUsersRequest

@typing.final
class ListUsersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.users.user_pb2.User]: ...
    def __init__(
        self,
        *,
        users: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.users.user_pb2.User] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "users", b"users"]) -> None: ...

global___ListUsersResponse = ListUsersResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.logging.v1.log_entry_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ReadRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    CRITERIA_FIELD_NUMBER: builtins.int
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ReadResponse.next_page_token] or [ReadResponse.previous_page_token] returned by a previous read request.
    """
    @property
    def criteria(self) -> global___Criteria:
        """Read criteria.

        See [Criteria] for details.
        """

    def __init__(
        self,
        *,
        page_token: builtins.str = ...,
        criteria: global___Criteria | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["criteria", b"criteria", "page_token", b"page_token", "selector", b"selector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["criteria", b"criteria", "page_token", b"page_token", "selector", b"selector"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["selector", b"selector"]) -> typing.Literal["page_token", "criteria"] | None: ...

global___ReadRequest = ReadRequest

@typing.final
class ReadResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PREVIOUS_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """Log group ID the read was performed from."""
    next_page_token: builtins.str
    """Token for getting the next page of the log entries.

    After getting log entries initially with [Criteria], you can use `next_page_token` as the value
    for the [ReadRequest.page_token] parameter in the next read request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    previous_page_token: builtins.str
    """Token for getting the previous page of the log entries.

    After getting log entries initially with [Criteria], you can use `previous_page_token` as the value
    for the [ReadRequest.page_token] parameter in the next read request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.logging.v1.log_entry_pb2.LogEntry]:
        """List of matching log entries."""

    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        entries: collections.abc.Iterable[yandex.cloud.logging.v1.log_entry_pb2.LogEntry] | None = ...,
        next_page_token: builtins.str = ...,
        previous_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["entries", b"entries", "log_group_id", b"log_group_id", "next_page_token", b"next_page_token", "previous_page_token", b"previous_page_token"]) -> None: ...

global___ReadResponse = ReadResponse

@typing.final
class Criteria(google.protobuf.message.Message):
    """Read criteria. Should be used in initial [ReadRequest]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPES_FIELD_NUMBER: builtins.int
    RESOURCE_IDS_FIELD_NUMBER: builtins.int
    SINCE_FIELD_NUMBER: builtins.int
    UNTIL_FIELD_NUMBER: builtins.int
    LEVELS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    STREAM_NAMES_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    MAX_RESPONSE_SIZE_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """ID of the log group to return.

    To get a log group ID make a [LogGroupService.List] request.
    """
    filter: builtins.str
    """Filter expression. For details about filtering, see [documentation](/docs/logging/concepts/filter)."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    max_response_size: builtins.int
    """Limits response to maximum size in bytes. Prevents gRPC resource exhaustion.

    Default value for max response size is 3.5 MiB
    """
    @property
    def resource_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of resource types to limit log entries to.

        Empty list disables filter.
        """

    @property
    def resource_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of resource IDs to limit log entries to.

        Empty list disables filter.
        """

    @property
    def since(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Lower bound of log entries timestamps."""

    @property
    def until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Upper bound of log entries timestamps."""

    @property
    def levels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType]:
        """List of log levels to limit log entries to.

        Empty list disables filter.
        """

    @property
    def stream_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of stream names to limit log entries to.

        Empty list disables filter.
        """

    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        resource_types: collections.abc.Iterable[builtins.str] | None = ...,
        resource_ids: collections.abc.Iterable[builtins.str] | None = ...,
        since: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        levels: collections.abc.Iterable[yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType] | None = ...,
        filter: builtins.str = ...,
        stream_names: collections.abc.Iterable[builtins.str] | None = ...,
        page_size: builtins.int = ...,
        max_response_size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["since", b"since", "until", b"until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "levels", b"levels", "log_group_id", b"log_group_id", "max_response_size", b"max_response_size", "page_size", b"page_size", "resource_ids", b"resource_ids", "resource_types", b"resource_types", "since", b"since", "stream_names", b"stream_names", "until", b"until"]) -> None: ...

global___Criteria = Criteria



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.message
import typing
import yandex.cloud.containerregistry.v1.scan_policy_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetScanPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_POLICY_ID_FIELD_NUMBER: builtins.int
    scan_policy_id: builtins.str
    """ID of the scan policy."""
    def __init__(
        self,
        *,
        scan_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["scan_policy_id", b"scan_policy_id"]) -> None: ...

global___GetScanPolicyRequest = GetScanPolicyRequest

@typing.final
class GetScanPolicyByRegistryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry with scan policy."""
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["registry_id", b"registry_id"]) -> None: ...

global___GetScanPolicyByRegistryRequest = GetScanPolicyByRegistryRequest

@typing.final
class CreateScanPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the scan policy registry."""
    name: builtins.str
    """Name of the scan policy."""
    description: builtins.str
    """Description of the scan policy."""
    @property
    def rules(self) -> yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanRules:
        """Rules of the scan policy."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        rules: yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanRules | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rules", b"rules"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "registry_id", b"registry_id", "rules", b"rules"]) -> None: ...

global___CreateScanPolicyRequest = CreateScanPolicyRequest

@typing.final
class UpdateScanPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_POLICY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    scan_policy_id: builtins.str
    """ID of the scan policy."""
    name: builtins.str
    """Name of the scan policy."""
    description: builtins.str
    """Description of the scan policy."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the scan policy resource are going to be updated."""

    @property
    def rules(self) -> yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanRules:
        """Rules of the scan policy."""

    def __init__(
        self,
        *,
        scan_policy_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        rules: yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanRules | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rules", b"rules", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "rules", b"rules", "scan_policy_id", b"scan_policy_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateScanPolicyRequest = UpdateScanPolicyRequest

@typing.final
class DeleteScanPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_POLICY_ID_FIELD_NUMBER: builtins.int
    scan_policy_id: builtins.str
    """ID of the scan policy."""
    def __init__(
        self,
        *,
        scan_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["scan_policy_id", b"scan_policy_id"]) -> None: ...

global___DeleteScanPolicyRequest = DeleteScanPolicyRequest

@typing.final
class CreateScanPolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_POLICY_ID_FIELD_NUMBER: builtins.int
    scan_policy_id: builtins.str
    """ID of created scan policy resource."""
    def __init__(
        self,
        *,
        scan_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["scan_policy_id", b"scan_policy_id"]) -> None: ...

global___CreateScanPolicyMetadata = CreateScanPolicyMetadata

@typing.final
class UpdateScanPolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_POLICY_ID_FIELD_NUMBER: builtins.int
    scan_policy_id: builtins.str
    """ID of the scan policy resource that is updated."""
    def __init__(
        self,
        *,
        scan_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["scan_policy_id", b"scan_policy_id"]) -> None: ...

global___UpdateScanPolicyMetadata = UpdateScanPolicyMetadata

@typing.final
class DeleteScanPolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCAN_POLICY_ID_FIELD_NUMBER: builtins.int
    scan_policy_id: builtins.str
    """ID of the scan policy resource that is deleted."""
    def __init__(
        self,
        *,
        scan_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["scan_policy_id", b"scan_policy_id"]) -> None: ...

global___DeleteScanPolicyMetadata = DeleteScanPolicyMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/triggers/v1/predicate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/serverless/triggers/v1/predicate.proto\x12#yandex.cloud.serverless.triggers.v1\x1a\x1dyandex/cloud/validation.proto\"\xcb\x01\n\tPredicate\x12J\n\rand_predicate\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.serverless.triggers.v1.AndPredicateH\x00\x12Y\n\x15\x66ield_value_predicate\x18\x04 \x01(\x0b\x32\x38.yandex.cloud.serverless.triggers.v1.FieldValuePredicateH\x00\x42\x11\n\tpredicate\x12\x04\xc0\xc1\x31\x01J\x04\x08\x03\x10\x04\"Q\n\x0c\x41ndPredicate\x12\x41\n\tpredicate\x18\x01 \x03(\x0b\x32..yandex.cloud.serverless.triggers.v1.Predicate\"\x7f\n\x13\x46ieldValuePredicate\x12\x18\n\nfield_path\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x05\x65xact\x18\x03 \x01(\tH\x00\x12\x10\n\x06prefix\x18\x08 \x01(\tH\x00\x12\x10\n\x06suffix\x18\t \x01(\tH\x00\x42\r\n\x05value\x12\x04\xc0\xc1\x31\x01J\x04\x08\x04\x10\x08J\x04\x08\x02\x10\x03\x42{\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.triggers.v1.predicate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggers'
  _PREDICATE.oneofs_by_name['predicate']._options = None
  _PREDICATE.oneofs_by_name['predicate']._serialized_options = b'\300\3011\001'
  _FIELDVALUEPREDICATE.oneofs_by_name['value']._options = None
  _FIELDVALUEPREDICATE.oneofs_by_name['value']._serialized_options = b'\300\3011\001'
  _FIELDVALUEPREDICATE.fields_by_name['field_path']._options = None
  _FIELDVALUEPREDICATE.fields_by_name['field_path']._serialized_options = b'\350\3071\001'
  _globals['_PREDICATE']._serialized_start=124
  _globals['_PREDICATE']._serialized_end=327
  _globals['_ANDPREDICATE']._serialized_start=329
  _globals['_ANDPREDICATE']._serialized_end=410
  _globals['_FIELDVALUEPREDICATE']._serialized_start=412
  _globals['_FIELDVALUEPREDICATE']._serialized_end=539
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UserAccount(google.protobuf.message.Message):
    """Currently represents only [Yandex account](/docs/iam/concepts/#passport)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    YANDEX_PASSPORT_USER_ACCOUNT_FIELD_NUMBER: builtins.int
    SAML_USER_ACCOUNT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the user account."""
    @property
    def yandex_passport_user_account(self) -> global___YandexPassportUserAccount:
        """A YandexPassportUserAccount resource."""

    @property
    def saml_user_account(self) -> global___SamlUserAccount:
        """A SAML federated user."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        yandex_passport_user_account: global___YandexPassportUserAccount | None = ...,
        saml_user_account: global___SamlUserAccount | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["saml_user_account", b"saml_user_account", "user_account", b"user_account", "yandex_passport_user_account", b"yandex_passport_user_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "saml_user_account", b"saml_user_account", "user_account", b"user_account", "yandex_passport_user_account", b"yandex_passport_user_account"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["user_account", b"user_account"]) -> typing.Literal["yandex_passport_user_account", "saml_user_account"] | None: ...

global___UserAccount = UserAccount

@typing.final
class YandexPassportUserAccount(google.protobuf.message.Message):
    """A YandexPassportUserAccount resource.
    For more information, see [Yandex account](/docs/iam/concepts/#passport).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGIN_FIELD_NUMBER: builtins.int
    DEFAULT_EMAIL_FIELD_NUMBER: builtins.int
    login: builtins.str
    """Login of the Yandex user account."""
    default_email: builtins.str
    """Default email of the Yandex user account."""
    def __init__(
        self,
        *,
        login: builtins.str = ...,
        default_email: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default_email", b"default_email", "login", b"login"]) -> None: ...

global___YandexPassportUserAccount = YandexPassportUserAccount

@typing.final
class SamlUserAccount(google.protobuf.message.Message):
    """A SAML federated user.
    For more information, see [federations](/docs/iam/concepts/users/saml-federations).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Attribute(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VALUE_FIELD_NUMBER: builtins.int
        @property
        def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            value: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

    @typing.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___SamlUserAccount.Attribute: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___SamlUserAccount.Attribute | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    NAME_ID_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation that the federation belongs to."""
    name_id: builtins.str
    """Name Id of the SAML federated user.
    The name is unique within the federation. 1-256 characters long.
    """
    @property
    def attributes(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___SamlUserAccount.Attribute]:
        """Additional attributes of the SAML federated user."""

    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        name_id: builtins.str = ...,
        attributes: collections.abc.Mapping[builtins.str, global___SamlUserAccount.Attribute] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["attributes", b"attributes", "federation_id", b"federation_id", "name_id", b"name_id"]) -> None: ...

global___SamlUserAccount = SamlUserAccount



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/backup/v1/backup.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.backup.v1 import policy_pb2 as yandex_dot_cloud_dot_backup_dot_v1_dot_policy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/backup/v1/backup.proto\x12\x16yandex.cloud.backup.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\x1a#yandex/cloud/backup/v1/policy.proto\"\xc1\x08\n\x07\x41rchive\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08vault_id\x18\x03 \x01(\t\x12\x45\n\nattributes\x18\x04 \x01(\x0b\x32\x31.yandex.cloud.backup.v1.Archive.ArchiveAttributes\x12\x0c\n\x04size\x18\x05 \x01(\x03\x12\x1c\n\x14\x63ompressed_data_size\x18\x06 \x01(\x03\x12\x11\n\tdata_size\x18\x07 \x01(\x03\x12\x1a\n\x12original_data_size\x18\x08 \x01(\x03\x12\x14\n\x0clogical_size\x18\t \x01(\x03\x12.\n\x06\x66ormat\x18\n \x01(\x0e\x32\x1e.yandex.cloud.backup.v1.Format\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_backup_created_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0clast_seen_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15protected_by_password\x18\x0f \x01(\x08\x12Q\n\x14\x65ncryption_algorithm\x18\x10 \x01(\x0e\x32\x33.yandex.cloud.backup.v1.Archive.EncryptionAlgorithm\x12\x37\n\x07\x61\x63tions\x18\x14 \x03(\x0e\x32&.yandex.cloud.backup.v1.Archive.Action\x12\x16\n\x0e\x62\x61\x63kup_plan_id\x18\x16 \x01(\t\x12\x18\n\x10\x62\x61\x63kup_plan_name\x18\x17 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x18 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x19 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x1a \x01(\t\x12\x12\n\nconsistent\x18\x1b \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x1e \x01(\x08\x12\x13\n\x0bresource_id\x18\x1f \x01(\t\x1a.\n\x11\x41rchiveAttributes\x12\x0c\n\x04\x61\x61ib\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"i\n\x13\x45ncryptionAlgorithm\x12$\n ENCRYPTION_ALGORITHM_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06\x41\x45S128\x10\x02\x12\n\n\x06\x41\x45S192\x10\x03\x12\n\n\x06\x41\x45S256\x10\x04\"B\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x0b\n\x07REFRESH\x10\x01\x12\x13\n\x0f\x44\x45LETE_BY_AGENT\x10\x02J\x04\x08\x11\x10\x14J\x04\x08\x15\x10\x16J\x04\x08\x1c\x10\x1dJ\x04\x08\x1d\x10\x1e\"u\n\x06Volume\x12\x12\n\nfree_space\x18\x01 \x01(\x03\x12\x13\n\x0bis_bootable\x18\x02 \x01(\x08\x12\x11\n\tis_system\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x03\x12\x13\n\x0bmount_strid\x18\x06 \x01(\t\"i\n\x04\x44isk\x12\x14\n\x0c\x64\x65vice_model\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12/\n\x07volumes\x18\x04 \x03(\x0b\x32\x1e.yandex.cloud.backup.v1.Volume\"\xfa\x04\n\x06\x42\x61\x63kup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08vault_id\x18\x02 \x01(\t\x12\x12\n\narchive_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0clast_seen_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04size\x18\x06 \x01(\x03\x12\x19\n\x11\x64\x65\x64uplicated_size\x18\x07 \x01(\x03\x12\x1b\n\x13\x62\x61\x63ked_up_data_size\x18\x08 \x01(\x03\x12\x1a\n\x12original_data_size\x18\t \x01(\x03\x12\x43\n\nattributes\x18\n \x01(\x0b\x32/.yandex.cloud.backup.v1.Backup.BackupAttributes\x12\x1b\n\x13\x63ompute_instance_id\x18\x0b \x01(\t\x12+\n\x05\x64isks\x18\x0e \x03(\x0b\x32\x1c.yandex.cloud.backup.v1.Disk\x12\x31\n\x04type\x18\x0f \x01(\x0e\x32#.yandex.cloud.backup.v1.Backup.Type\x12\x0f\n\x07\x64\x65leted\x18\x15 \x01(\x08\x12\x11\n\tpolicy_id\x18\x16 \x01(\t\x12\x13\n\x0bresource_id\x18\x17 \x01(\t\x1a\x34\n\x10\x42\x61\x63kupAttributes\x12\x13\n\x0bstream_name\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"7\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x0f\n\x0bINCREMENTAL\x10\x02J\x04\x08\x0c\x10\rJ\x04\x08\r\x10\x0eJ\x04\x08\x10\x10\x15\"\xc4\x03\n\nBackupFile\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\tparent_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\xe8\xc7\x31\x00\x12;\n\x04type\x18\x03 \x01(\x0e\x32\'.yandex.cloud.backup.v1.BackupFile.TypeB\x04\xe8\xc7\x31\x01\x12\x17\n\tfull_path\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04name\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04size\x18\x06 \x01(\x03\x12\x41\n\x07\x61\x63tions\x18\x07 \x01(\x0b\x32*.yandex.cloud.backup.v1.BackupFile.ActionsB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bmodified_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x1a@\n\x07\x41\x63tions\x12\x17\n\x0frestore_to_disk\x18\x01 \x01(\x08\x12\x16\n\x0ego_to_location\x18\x02 \x01(\x08J\x04\x08\x03\x10\x04\"9\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08TYPE_DIR\x10\x01\x12\r\n\tTYPE_FILE\x10\x02\x42_\n\x1ayandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.backup.v1.backup_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backup'
  _BACKUPFILE.fields_by_name['id']._options = None
  _BACKUPFILE.fields_by_name['id']._serialized_options = b'\350\3071\001'
  _BACKUPFILE.fields_by_name['parent_id']._options = None
  _BACKUPFILE.fields_by_name['parent_id']._serialized_options = b'\350\3071\000'
  _BACKUPFILE.fields_by_name['type']._options = None
  _BACKUPFILE.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _BACKUPFILE.fields_by_name['full_path']._options = None
  _BACKUPFILE.fields_by_name['full_path']._serialized_options = b'\350\3071\001'
  _BACKUPFILE.fields_by_name['name']._options = None
  _BACKUPFILE.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _BACKUPFILE.fields_by_name['actions']._options = None
  _BACKUPFILE.fields_by_name['actions']._serialized_options = b'\350\3071\001'
  _BACKUPFILE.fields_by_name['modified_at']._options = None
  _BACKUPFILE.fields_by_name['modified_at']._serialized_options = b'\350\3071\001'
  _globals['_ARCHIVE']._serialized_start=197
  _globals['_ARCHIVE']._serialized_end=1286
  _globals['_ARCHIVE_ARCHIVEATTRIBUTES']._serialized_start=1041
  _globals['_ARCHIVE_ARCHIVEATTRIBUTES']._serialized_end=1087
  _globals['_ARCHIVE_ENCRYPTIONALGORITHM']._serialized_start=1089
  _globals['_ARCHIVE_ENCRYPTIONALGORITHM']._serialized_end=1194
  _globals['_ARCHIVE_ACTION']._serialized_start=1196
  _globals['_ARCHIVE_ACTION']._serialized_end=1262
  _globals['_VOLUME']._serialized_start=1288
  _globals['_VOLUME']._serialized_end=1405
  _globals['_DISK']._serialized_start=1407
  _globals['_DISK']._serialized_end=1512
  _globals['_BACKUP']._serialized_start=1515
  _globals['_BACKUP']._serialized_end=2149
  _globals['_BACKUP_BACKUPATTRIBUTES']._serialized_start=2022
  _globals['_BACKUP_BACKUPATTRIBUTES']._serialized_end=2074
  _globals['_BACKUP_TYPE']._serialized_start=2076
  _globals['_BACKUP_TYPE']._serialized_end=2131
  _globals['_BACKUPFILE']._serialized_start=2152
  _globals['_BACKUPFILE']._serialized_end=2604
  _globals['_BACKUPFILE_ACTIONS']._serialized_start=2481
  _globals['_BACKUPFILE_ACTIONS']._serialized_end=2545
  _globals['_BACKUPFILE_TYPE']._serialized_start=2547
  _globals['_BACKUPFILE_TYPE']._serialized_end=2604
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2
import yandex.cloud.ai.common.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateSearchIndexRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    FILE_IDS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TEXT_SEARCH_INDEX_FIELD_NUMBER: builtins.int
    VECTOR_SEARCH_INDEX_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def file_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def text_search_index(self) -> yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.TextSearchIndex: ...
    @property
    def vector_search_index(self) -> yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.VectorSearchIndex: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        file_ids: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        text_search_index: yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.TextSearchIndex | None = ...,
        vector_search_index: yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.VectorSearchIndex | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["IndexType", b"IndexType", "expiration_config", b"expiration_config", "text_search_index", b"text_search_index", "vector_search_index", b"vector_search_index"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["IndexType", b"IndexType", "description", b"description", "expiration_config", b"expiration_config", "file_ids", b"file_ids", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "text_search_index", b"text_search_index", "vector_search_index", b"vector_search_index"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["IndexType", b"IndexType"]) -> typing.Literal["text_search_index", "vector_search_index"] | None: ...

global___CreateSearchIndexRequest = CreateSearchIndexRequest

@typing.final
class GetSearchIndexRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_ID_FIELD_NUMBER: builtins.int
    search_index_id: builtins.str
    def __init__(
        self,
        *,
        search_index_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["search_index_id", b"search_index_id"]) -> None: ...

global___GetSearchIndexRequest = GetSearchIndexRequest

@typing.final
class UpdateSearchIndexRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SEARCH_INDEX_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    search_index_id: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        search_index_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiration_config", b"expiration_config", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "expiration_config", b"expiration_config", "labels", b"labels", "name", b"name", "search_index_id", b"search_index_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateSearchIndexRequest = UpdateSearchIndexRequest

@typing.final
class DeleteSearchIndexRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_ID_FIELD_NUMBER: builtins.int
    search_index_id: builtins.str
    def __init__(
        self,
        *,
        search_index_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["search_index_id", b"search_index_id"]) -> None: ...

global___DeleteSearchIndexRequest = DeleteSearchIndexRequest

@typing.final
class DeleteSearchIndexResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteSearchIndexResponse = DeleteSearchIndexResponse

@typing.final
class ListSearchIndicesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSearchIndicesRequest = ListSearchIndicesRequest

@typing.final
class ListSearchIndicesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDICES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def indices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex]: ...
    def __init__(
        self,
        *,
        indices: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["indices", b"indices", "next_page_token", b"next_page_token"]) -> None: ...

global___ListSearchIndicesResponse = ListSearchIndicesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LogGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LogGroup._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: LogGroup._Status.ValueType  # 0
        """Unknown status.

        Should never occur.
        """
        CREATING: LogGroup._Status.ValueType  # 1
        """Log group is creating."""
        ACTIVE: LogGroup._Status.ValueType  # 2
        """Log group is ready to accept messages,"""
        DELETING: LogGroup._Status.ValueType  # 3
        """Log group is being deleted.

        No messages will be accepted.
        """
        ERROR: LogGroup._Status.ValueType  # 4
        """Log group is in failed state."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Possible log group statuses."""

    STATUS_UNSPECIFIED: LogGroup.Status.ValueType  # 0
    """Unknown status.

    Should never occur.
    """
    CREATING: LogGroup.Status.ValueType  # 1
    """Log group is creating."""
    ACTIVE: LogGroup.Status.ValueType  # 2
    """Log group is ready to accept messages,"""
    DELETING: LogGroup.Status.ValueType  # 3
    """Log group is being deleted.

    No messages will be accepted.
    """
    ERROR: LogGroup.Status.ValueType  # 4
    """Log group is in failed state."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    DATA_STREAM_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Log group ID."""
    folder_id: builtins.str
    """Log group folder ID."""
    cloud_id: builtins.str
    """Log group cloud ID."""
    name: builtins.str
    """Log group name."""
    description: builtins.str
    """Log group description."""
    status: global___LogGroup.Status.ValueType
    """Status of the log group."""
    data_stream: builtins.str
    """Data stream name"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Log group creation time."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Log group labels."""

    @property
    def retention_period(self) -> google.protobuf.duration_pb2.Duration:
        """Log group entry retention period.

        Entries will be present in group during this period.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___LogGroup.Status.ValueType = ...,
        retention_period: google.protobuf.duration_pb2.Duration | None = ...,
        data_stream: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "retention_period", b"retention_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "data_stream", b"data_stream", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "retention_period", b"retention_period", "status", b"status"]) -> None: ...

global___LogGroup = LogGroup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/episode_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import episode_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_episode__pb2
from yandex.cloud.video.v1 import manifest_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_manifest__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/video/v1/episode_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a#yandex/cloud/video/v1/episode.proto\x1a$yandex/cloud/video/v1/manifest.proto\"\'\n\x11GetEpisodeRequest\x12\x12\n\nepisode_id\x18\x01 \x01(\t\"\x99\x01\n\x13ListEpisodesRequest\x12\x13\n\tstream_id\x18\x01 \x01(\tH\x00\x12\x11\n\x07line_id\x18\x02 \x01(\tH\x00\x12\x11\n\tpage_size\x18\x64 \x01(\x03\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tB\x0b\n\tparent_idJ\x04\x08\x03\x10\x64\"g\n\x14ListEpisodesResponse\x12\x30\n\x08\x65pisodes\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.video.v1.Episode\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xc8\x03\n\x14\x43reateEpisodeRequest\x12\x13\n\tstream_id\x18\x64 \x01(\tH\x00\x12\x11\n\x07line_id\x18\x65 \x01(\tH\x00\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x04 \x01(\t\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inish_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64vr_seconds\x18\x07 \x01(\x03\x12J\n\rpublic_access\x18\xe8\x07 \x01(\x0b\x32\x30.yandex.cloud.video.v1.EpisodePublicAccessParamsH\x01\x12S\n\x12\x61uth_system_access\x18\xea\x07 \x01(\x0b\x32\x34.yandex.cloud.video.v1.EpisodeAuthSystemAccessParamsH\x01\x42\x0b\n\tparent_idB\x0f\n\raccess_rightsJ\x05\x08\x66\x10\xe8\x07J\x04\x08\x08\x10\x64J\x04\x08\x01\x10\x02J\x06\x08\xe9\x07\x10\xea\x07\"\x1b\n\x19\x45pisodePublicAccessParams\"\x1f\n\x1d\x45pisodeAuthSystemAccessParams\"+\n\x15\x43reateEpisodeMetadata\x12\x12\n\nepisode_id\x18\x01 \x01(\t\"\xcb\x03\n\x14UpdateEpisodeRequest\x12\x12\n\nepisode_id\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x05 \x01(\t\x12.\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inish_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64vr_seconds\x18\x08 \x01(\x03\x12J\n\rpublic_access\x18\xe8\x07 \x01(\x0b\x32\x30.yandex.cloud.video.v1.EpisodePublicAccessParamsH\x00\x12S\n\x12\x61uth_system_access\x18\xea\x07 \x01(\x0b\x32\x34.yandex.cloud.video.v1.EpisodeAuthSystemAccessParamsH\x00\x42\x0f\n\raccess_rightsJ\x05\x08\t\x10\xe8\x07J\x06\x08\xe9\x07\x10\xea\x07\"+\n\x15UpdateEpisodeMetadata\x12\x12\n\nepisode_id\x18\x01 \x01(\t\"*\n\x14\x44\x65leteEpisodeRequest\x12\x12\n\nepisode_id\x18\x01 \x01(\t\"+\n\x15\x44\x65leteEpisodeMetadata\x12\x12\n\nepisode_id\x18\x01 \x01(\t\"\xd8\x01\n\x1bPerformEpisodeActionRequest\x12\x12\n\nepisode_id\x18\x01 \x01(\t\x12?\n\x07publish\x18\xea\x07 \x01(\x0b\x32+.yandex.cloud.video.v1.PublishEpisodeActionH\x00\x12\x43\n\tunpublish\x18\xeb\x07 \x01(\x0b\x32-.yandex.cloud.video.v1.UnpublishEpisodeActionH\x00\x42\x08\n\x06\x61\x63tionJ\x05\x08\x02\x10\xe8\x07J\x06\x08\xe8\x07\x10\xe9\x07J\x06\x08\xe9\x07\x10\xea\x07\"\x16\n\x14PublishEpisodeAction\"\x18\n\x16UnpublishEpisodeAction\"2\n\x1cPerformEpisodeActionMetadata\x12\x12\n\nepisode_id\x18\x01 \x01(\t\"l\n\x1aGetEpisodePlayerURLRequest\x12\x12\n\nepisode_id\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x01(\x0b\x32*.yandex.cloud.video.v1.EpisodePlayerParams\"E\n\x13\x45pisodePlayerParams\x12\x0c\n\x04mute\x18\x01 \x01(\x08\x12\x10\n\x08\x61utoplay\x18\x02 \x01(\x08\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\"?\n\x1bGetEpisodePlayerURLResponse\x12\x12\n\nplayer_url\x18\x01 \x01(\t\x12\x0c\n\x04html\x18\x02 \x01(\t\"0\n\x1aGetEpisodeManifestsRequest\x12\x12\n\nepisode_id\x18\x01 \x01(\t\"Q\n\x1bGetEpisodeManifestsResponse\x12\x32\n\tmanifests\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.video.v1.Manifest2\xb0\n\n\x0e\x45pisodeService\x12x\n\x03Get\x12(.yandex.cloud.video.v1.GetEpisodeRequest\x1a\x1e.yandex.cloud.video.v1.Episode\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/video/v1/episodes/{episode_id}\x12{\n\x04List\x12*.yandex.cloud.video.v1.ListEpisodesRequest\x1a+.yandex.cloud.video.v1.ListEpisodesResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/video/v1/episodes\x12\x9b\x01\n\x06\x43reate\x12+.yandex.cloud.video.v1.CreateEpisodeRequest\x1a!.yandex.cloud.operation.Operation\"A\xb2\xd2* \n\x15\x43reateEpisodeMetadata\x12\x07\x45pisode\x82\xd3\xe4\x93\x02\x17\"\x12/video/v1/episodes:\x01*\x12\xa8\x01\n\x06Update\x12+.yandex.cloud.video.v1.UpdateEpisodeRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2* \n\x15UpdateEpisodeMetadata\x12\x07\x45pisode\x82\xd3\xe4\x93\x02$2\x1f/video/v1/episodes/{episode_id}:\x01*\x12\xb3\x01\n\x06\x44\x65lete\x12+.yandex.cloud.video.v1.DeleteEpisodeRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*.\n\x15\x44\x65leteEpisodeMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/video/v1/episodes/{episode_id}\x12\xcb\x01\n\rPerformAction\x12\x32.yandex.cloud.video.v1.PerformEpisodeActionRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*\'\n\x1cPerformEpisodeActionMetadata\x12\x07\x45pisode\x82\xd3\xe4\x93\x02\x32\"-/video/v1/episodes/{episode_id}:performAction:\x01*\x12\xab\x01\n\x0cGetPlayerURL\x12\x31.yandex.cloud.video.v1.GetEpisodePlayerURLRequest\x1a\x32.yandex.cloud.video.v1.GetEpisodePlayerURLResponse\"4\x82\xd3\xe4\x93\x02.\x12,/video/v1/episodes/{episode_id}:getPlayerUrl\x12\xab\x01\n\x0cGetManifests\x12\x31.yandex.cloud.video.v1.GetEpisodeManifestsRequest\x1a\x32.yandex.cloud.video.v1.GetEpisodeManifestsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/video/v1/episodes/{episode_id}:getManifestsB\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.episode_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _EPISODESERVICE.methods_by_name['Get']._options = None
  _EPISODESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/video/v1/episodes/{episode_id}'
  _EPISODESERVICE.methods_by_name['List']._options = None
  _EPISODESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\024\022\022/video/v1/episodes'
  _EPISODESERVICE.methods_by_name['Create']._options = None
  _EPISODESERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateEpisodeMetadata\022\007Episode\202\323\344\223\002\027\"\022/video/v1/episodes:\001*'
  _EPISODESERVICE.methods_by_name['Update']._options = None
  _EPISODESERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateEpisodeMetadata\022\007Episode\202\323\344\223\002$2\037/video/v1/episodes/{episode_id}:\001*'
  _EPISODESERVICE.methods_by_name['Delete']._options = None
  _EPISODESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteEpisodeMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/video/v1/episodes/{episode_id}'
  _EPISODESERVICE.methods_by_name['PerformAction']._options = None
  _EPISODESERVICE.methods_by_name['PerformAction']._serialized_options = b'\262\322*\'\n\034PerformEpisodeActionMetadata\022\007Episode\202\323\344\223\0022\"-/video/v1/episodes/{episode_id}:performAction:\001*'
  _EPISODESERVICE.methods_by_name['GetPlayerURL']._options = None
  _EPISODESERVICE.methods_by_name['GetPlayerURL']._serialized_options = b'\202\323\344\223\002.\022,/video/v1/episodes/{episode_id}:getPlayerUrl'
  _EPISODESERVICE.methods_by_name['GetManifests']._options = None
  _EPISODESERVICE.methods_by_name['GetManifests']._serialized_options = b'\202\323\344\223\002.\022,/video/v1/episodes/{episode_id}:getManifests'
  _globals['_GETEPISODEREQUEST']._serialized_start=316
  _globals['_GETEPISODEREQUEST']._serialized_end=355
  _globals['_LISTEPISODESREQUEST']._serialized_start=358
  _globals['_LISTEPISODESREQUEST']._serialized_end=511
  _globals['_LISTEPISODESRESPONSE']._serialized_start=513
  _globals['_LISTEPISODESRESPONSE']._serialized_end=616
  _globals['_CREATEEPISODEREQUEST']._serialized_start=619
  _globals['_CREATEEPISODEREQUEST']._serialized_end=1075
  _globals['_EPISODEPUBLICACCESSPARAMS']._serialized_start=1077
  _globals['_EPISODEPUBLICACCESSPARAMS']._serialized_end=1104
  _globals['_EPISODEAUTHSYSTEMACCESSPARAMS']._serialized_start=1106
  _globals['_EPISODEAUTHSYSTEMACCESSPARAMS']._serialized_end=1137
  _globals['_CREATEEPISODEMETADATA']._serialized_start=1139
  _globals['_CREATEEPISODEMETADATA']._serialized_end=1182
  _globals['_UPDATEEPISODEREQUEST']._serialized_start=1185
  _globals['_UPDATEEPISODEREQUEST']._serialized_end=1644
  _globals['_UPDATEEPISODEMETADATA']._serialized_start=1646
  _globals['_UPDATEEPISODEMETADATA']._serialized_end=1689
  _globals['_DELETEEPISODEREQUEST']._serialized_start=1691
  _globals['_DELETEEPISODEREQUEST']._serialized_end=1733
  _globals['_DELETEEPISODEMETADATA']._serialized_start=1735
  _globals['_DELETEEPISODEMETADATA']._serialized_end=1778
  _globals['_PERFORMEPISODEACTIONREQUEST']._serialized_start=1781
  _globals['_PERFORMEPISODEACTIONREQUEST']._serialized_end=1997
  _globals['_PUBLISHEPISODEACTION']._serialized_start=1999
  _globals['_PUBLISHEPISODEACTION']._serialized_end=2021
  _globals['_UNPUBLISHEPISODEACTION']._serialized_start=2023
  _globals['_UNPUBLISHEPISODEACTION']._serialized_end=2047
  _globals['_PERFORMEPISODEACTIONMETADATA']._serialized_start=2049
  _globals['_PERFORMEPISODEACTIONMETADATA']._serialized_end=2099
  _globals['_GETEPISODEPLAYERURLREQUEST']._serialized_start=2101
  _globals['_GETEPISODEPLAYERURLREQUEST']._serialized_end=2209
  _globals['_EPISODEPLAYERPARAMS']._serialized_start=2211
  _globals['_EPISODEPLAYERPARAMS']._serialized_end=2280
  _globals['_GETEPISODEPLAYERURLRESPONSE']._serialized_start=2282
  _globals['_GETEPISODEPLAYERURLRESPONSE']._serialized_end=2345
  _globals['_GETEPISODEMANIFESTSREQUEST']._serialized_start=2347
  _globals['_GETEPISODEMANIFESTSREQUEST']._serialized_end=2395
  _globals['_GETEPISODEMANIFESTSRESPONSE']._serialized_start=2397
  _globals['_GETEPISODEMANIFESTSRESPONSE']._serialized_end=2478
  _globals['_EPISODESERVICE']._serialized_start=2481
  _globals['_EPISODESERVICE']._serialized_end=3809
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/smartwebsecurity/v1/advanced_rate_limiter/advanced_rate_limiter_profile.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.smartwebsecurity.v1 import security_profile_pb2 as yandex_dot_cloud_dot_smartwebsecurity_dot_v1_dot_security__profile__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZyandex/cloud/smartwebsecurity/v1/advanced_rate_limiter/advanced_rate_limiter_profile.proto\x12\x36yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x37yandex/cloud/smartwebsecurity/v1/security_profile.proto\x1a\x1dyandex/cloud/validation.proto\"\xb0\x04\n\x1a\x41\x64vancedRateLimiterProfile\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\xab\x01\n\x06labels\x18\x03 \x03(\x0b\x32^.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterProfile.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x38\n\x04name\x18\x04 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04\x31-50\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12t\n\x1b\x61\x64vanced_rate_limiter_rules\x18\x06 \x03(\x0b\x32O.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x63loud_id\x18\t \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x08\x10\t\"\xe3\x10\n\x17\x41\x64vancedRateLimiterRule\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04\x31-50\x12\x1e\n\x08priority\x18\x02 \x01(\x03\x42\x0c\xfa\xc7\x31\x08\x31-999999\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12\x0f\n\x07\x64ry_run\x18\x04 \x01(\x08\x12s\n\x0cstatic_quota\x18\x05 \x01(\x0b\x32[.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule.StaticQuotaH\x00\x12u\n\rdynamic_quota\x18\x06 \x01(\x0b\x32\\.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule.DynamicQuotaH\x00\x1a\xa7\x02\n\x0bStaticQuota\x12\x66\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32V.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule.Action\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.yandex.cloud.smartwebsecurity.v1.Condition\x12\"\n\x05limit\x18\x03 \x01(\x03\x42\x13\xfa\xc7\x31\x0f\x31-9999999999999\x12L\n\x06period\x18\x04 \x01(\x03\x42<\xfa\xc7\x31\x38\x31,5,10,30,60,120,180,240,300,600,900,1200,1800,2700,3600\x1a\xe2\n\n\x0c\x44ynamicQuota\x12\x66\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32V.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule.Action\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.yandex.cloud.smartwebsecurity.v1.Condition\x12\"\n\x05limit\x18\x03 \x01(\x03\x42\x13\xfa\xc7\x31\x0f\x31-9999999999999\x12L\n\x06period\x18\x04 \x01(\x03\x42<\xfa\xc7\x31\x38\x31,5,10,30,60,120,180,240,300,600,900,1200,1800,2700,3600\x12\x8d\x01\n\x0f\x63haracteristics\x18\x05 \x03(\x0b\x32k.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule.DynamicQuota.CharacteristicB\x07\x82\xc8\x31\x03<=3\x1a\xa7\x07\n\x0e\x43haracteristic\x12\xa2\x01\n\x15simple_characteristic\x18\x01 \x01(\x0b\x32\x80\x01.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristicH\x00\x12\x9b\x01\n\x12key_characteristic\x18\x02 \x01(\x0b\x32}.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristicH\x00\x12\x18\n\x10\x63\x61se_insensitive\x18\n \x01(\x08\x1a\x89\x02\n\x14SimpleCharacteristic\x12\x94\x01\n\x04type\x18\x01 \x01(\x0e\x32\x85\x01.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic.Type\"Z\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cREQUEST_PATH\x10\x01\x12\x0f\n\x0bHTTP_METHOD\x10\x02\x12\x06\n\x02IP\x10\x03\x12\x07\n\x03GEO\x10\x04\x12\x08\n\x04HOST\x10\x05\x1a\x83\x02\n\x11KeyCharacteristic\x12\x91\x01\n\x04type\x18\x01 \x01(\x0e\x32\x82\x01.yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic.Type\x12\r\n\x05value\x18\x02 \x01(\t\"K\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCOOKIE_KEY\x10\x01\x12\x0e\n\nHEADER_KEY\x10\x02\x12\r\n\tQUERY_KEY\x10\x03\x42 \n\x18\x63haracteristic_specifier\x12\x04\xc0\xc1\x31\x01J\x04\x08\x03\x10\n\"*\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x08\n\x04\x44\x45NY\x10\x01\x42\x16\n\x0erule_specifier\x12\x04\xc0\xc1\x31\x01\x42\xa9\x01\n:yandex.cloud.api.smartwebsecurity.v1.advanced_rate_limiterZkgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/advanced_rate_limiter;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n:yandex.cloud.api.smartwebsecurity.v1.advanced_rate_limiterZkgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/advanced_rate_limiter;smartwebsecurity'
  _ADVANCEDRATELIMITERPROFILE_LABELSENTRY._options = None
  _ADVANCEDRATELIMITERPROFILE_LABELSENTRY._serialized_options = b'8\001'
  _ADVANCEDRATELIMITERPROFILE.fields_by_name['labels']._options = None
  _ADVANCEDRATELIMITERPROFILE.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _ADVANCEDRATELIMITERPROFILE.fields_by_name['name']._options = None
  _ADVANCEDRATELIMITERPROFILE.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\0041-50'
  _ADVANCEDRATELIMITERPROFILE.fields_by_name['description']._options = None
  _ADVANCEDRATELIMITERPROFILE.fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _ADVANCEDRATELIMITERRULE_STATICQUOTA.fields_by_name['limit']._options = None
  _ADVANCEDRATELIMITERRULE_STATICQUOTA.fields_by_name['limit']._serialized_options = b'\372\3071\0171-9999999999999'
  _ADVANCEDRATELIMITERRULE_STATICQUOTA.fields_by_name['period']._options = None
  _ADVANCEDRATELIMITERRULE_STATICQUOTA.fields_by_name['period']._serialized_options = b'\372\307181,5,10,30,60,120,180,240,300,600,900,1200,1800,2700,3600'
  _ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC.oneofs_by_name['characteristic_specifier']._options = None
  _ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC.oneofs_by_name['characteristic_specifier']._serialized_options = b'\300\3011\001'
  _ADVANCEDRATELIMITERRULE_DYNAMICQUOTA.fields_by_name['limit']._options = None
  _ADVANCEDRATELIMITERRULE_DYNAMICQUOTA.fields_by_name['limit']._serialized_options = b'\372\3071\0171-9999999999999'
  _ADVANCEDRATELIMITERRULE_DYNAMICQUOTA.fields_by_name['period']._options = None
  _ADVANCEDRATELIMITERRULE_DYNAMICQUOTA.fields_by_name['period']._serialized_options = b'\372\307181,5,10,30,60,120,180,240,300,600,900,1200,1800,2700,3600'
  _ADVANCEDRATELIMITERRULE_DYNAMICQUOTA.fields_by_name['characteristics']._options = None
  _ADVANCEDRATELIMITERRULE_DYNAMICQUOTA.fields_by_name['characteristics']._serialized_options = b'\202\3101\003<=3'
  _ADVANCEDRATELIMITERRULE.oneofs_by_name['rule_specifier']._options = None
  _ADVANCEDRATELIMITERRULE.oneofs_by_name['rule_specifier']._serialized_options = b'\300\3011\001'
  _ADVANCEDRATELIMITERRULE.fields_by_name['name']._options = None
  _ADVANCEDRATELIMITERRULE.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\0041-50'
  _ADVANCEDRATELIMITERRULE.fields_by_name['priority']._options = None
  _ADVANCEDRATELIMITERRULE.fields_by_name['priority']._serialized_options = b'\372\3071\0101-999999'
  _ADVANCEDRATELIMITERRULE.fields_by_name['description']._options = None
  _ADVANCEDRATELIMITERRULE.fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _globals['_ADVANCEDRATELIMITERPROFILE']._serialized_start=272
  _globals['_ADVANCEDRATELIMITERPROFILE']._serialized_end=832
  _globals['_ADVANCEDRATELIMITERPROFILE_LABELSENTRY']._serialized_start=781
  _globals['_ADVANCEDRATELIMITERPROFILE_LABELSENTRY']._serialized_end=826
  _globals['_ADVANCEDRATELIMITERRULE']._serialized_start=835
  _globals['_ADVANCEDRATELIMITERRULE']._serialized_end=2982
  _globals['_ADVANCEDRATELIMITERRULE_STATICQUOTA']._serialized_start=1238
  _globals['_ADVANCEDRATELIMITERRULE_STATICQUOTA']._serialized_end=1533
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA']._serialized_start=1536
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA']._serialized_end=2914
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC']._serialized_start=1979
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC']._serialized_end=2914
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC_SIMPLECHARACTERISTIC']._serialized_start=2347
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC_SIMPLECHARACTERISTIC']._serialized_end=2612
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC_SIMPLECHARACTERISTIC_TYPE']._serialized_start=2522
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC_SIMPLECHARACTERISTIC_TYPE']._serialized_end=2612
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC_KEYCHARACTERISTIC']._serialized_start=2615
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC_KEYCHARACTERISTIC']._serialized_end=2874
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC_KEYCHARACTERISTIC_TYPE']._serialized_start=2799
  _globals['_ADVANCEDRATELIMITERRULE_DYNAMICQUOTA_CHARACTERISTIC_KEYCHARACTERISTIC_TYPE']._serialized_end=2874
  _globals['_ADVANCEDRATELIMITERRULE_ACTION']._serialized_start=2916
  _globals['_ADVANCEDRATELIMITERRULE_ACTION']._serialized_end=2958
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/topic_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.kafka.v1 import topic_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_topic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/mdb/kafka/v1/topic_service.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a%yandex/cloud/mdb/kafka/v1/topic.proto\"h\n\x0fGetTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\ntopic_name\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x05\x31-256\"s\n\x11ListTopicsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"_\n\x12ListTopicsResponse\x12\x30\n\x06topics\x18\x01 \x03(\x0b\x32 .yandex.cloud.mdb.kafka.v1.Topic\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"v\n\x12\x43reateTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\ntopic_spec\x18\x02 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.TopicSpecB\x04\xe8\xc7\x31\x01\"^\n\x13\x43reateTopicMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x33\n\ntopic_name\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x05<=256\"\xd6\x01\n\x12UpdateTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\ntopic_name\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x05\x31-256\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x38\n\ntopic_spec\x18\x04 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.TopicSpec\"=\n\x13UpdateTopicMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\ntopic_name\x18\x02 \x01(\t\"k\n\x12\x44\x65leteTopicRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\ntopic_name\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x05\x31-256\"=\n\x13\x44\x65leteTopicMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\ntopic_name\x18\x02 \x01(\t2\x96\x07\n\x0cTopicService\x12\x98\x01\n\x03Get\x12*.yandex.cloud.mdb.kafka.v1.GetTopicRequest\x1a .yandex.cloud.mdb.kafka.v1.Topic\"C\x82\xd3\xe4\x93\x02=\x12;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}\x12\x9b\x01\n\x04List\x12,.yandex.cloud.mdb.kafka.v1.ListTopicsRequest\x1a-.yandex.cloud.mdb.kafka.v1.ListTopicsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./managed-kafka/v1/clusters/{cluster_id}/topics\x12\xb5\x01\n\x06\x43reate\x12-.yandex.cloud.mdb.kafka.v1.CreateTopicRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*\x1c\n\x13\x43reateTopicMetadata\x12\x05Topic\x82\xd3\xe4\x93\x02\x33\"./managed-kafka/v1/clusters/{cluster_id}/topics:\x01*\x12\xc2\x01\n\x06Update\x12-.yandex.cloud.mdb.kafka.v1.UpdateTopicRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*\x1c\n\x13UpdateTopicMetadata\x12\x05Topic\x82\xd3\xe4\x93\x02@2;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}:\x01*\x12\xcf\x01\n\x06\x44\x65lete\x12-.yandex.cloud.mdb.kafka.v1.DeleteTopicRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*,\n\x13\x44\x65leteTopicMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=*;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}Bd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.topic_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _GETTOPICREQUEST.fields_by_name['cluster_id']._options = None
  _GETTOPICREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETTOPICREQUEST.fields_by_name['topic_name']._options = None
  _GETTOPICREQUEST.fields_by_name['topic_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\0051-256'
  _LISTTOPICSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTTOPICSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTTOPICSREQUEST.fields_by_name['page_size']._options = None
  _LISTTOPICSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTTOPICSREQUEST.fields_by_name['page_token']._options = None
  _LISTTOPICSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATETOPICREQUEST.fields_by_name['cluster_id']._options = None
  _CREATETOPICREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATETOPICREQUEST.fields_by_name['topic_spec']._options = None
  _CREATETOPICREQUEST.fields_by_name['topic_spec']._serialized_options = b'\350\3071\001'
  _CREATETOPICMETADATA.fields_by_name['topic_name']._options = None
  _CREATETOPICMETADATA.fields_by_name['topic_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\005<=256'
  _UPDATETOPICREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATETOPICREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATETOPICREQUEST.fields_by_name['topic_name']._options = None
  _UPDATETOPICREQUEST.fields_by_name['topic_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\0051-256'
  _DELETETOPICREQUEST.fields_by_name['cluster_id']._options = None
  _DELETETOPICREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETETOPICREQUEST.fields_by_name['topic_name']._options = None
  _DELETETOPICREQUEST.fields_by_name['topic_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\0051-256'
  _TOPICSERVICE.methods_by_name['Get']._options = None
  _TOPICSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002=\022;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}'
  _TOPICSERVICE.methods_by_name['List']._options = None
  _TOPICSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0020\022./managed-kafka/v1/clusters/{cluster_id}/topics'
  _TOPICSERVICE.methods_by_name['Create']._options = None
  _TOPICSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateTopicMetadata\022\005Topic\202\323\344\223\0023\"./managed-kafka/v1/clusters/{cluster_id}/topics:\001*'
  _TOPICSERVICE.methods_by_name['Update']._options = None
  _TOPICSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateTopicMetadata\022\005Topic\202\323\344\223\002@2;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}:\001*'
  _TOPICSERVICE.methods_by_name['Delete']._options = None
  _TOPICSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteTopicMetadata\022\025google.protobuf.Empty\202\323\344\223\002=*;/managed-kafka/v1/clusters/{cluster_id}/topics/{topic_name}'
  _globals['_GETTOPICREQUEST']._serialized_start=284
  _globals['_GETTOPICREQUEST']._serialized_end=388
  _globals['_LISTTOPICSREQUEST']._serialized_start=390
  _globals['_LISTTOPICSREQUEST']._serialized_end=505
  _globals['_LISTTOPICSRESPONSE']._serialized_start=507
  _globals['_LISTTOPICSRESPONSE']._serialized_end=602
  _globals['_CREATETOPICREQUEST']._serialized_start=604
  _globals['_CREATETOPICREQUEST']._serialized_end=722
  _globals['_CREATETOPICMETADATA']._serialized_start=724
  _globals['_CREATETOPICMETADATA']._serialized_end=818
  _globals['_UPDATETOPICREQUEST']._serialized_start=821
  _globals['_UPDATETOPICREQUEST']._serialized_end=1035
  _globals['_UPDATETOPICMETADATA']._serialized_start=1037
  _globals['_UPDATETOPICMETADATA']._serialized_end=1098
  _globals['_DELETETOPICREQUEST']._serialized_start=1100
  _globals['_DELETETOPICREQUEST']._serialized_end=1207
  _globals['_DELETETOPICMETADATA']._serialized_start=1209
  _globals['_DELETETOPICMETADATA']._serialized_end=1270
  _globals['_TOPICSERVICE']._serialized_start=1273
  _globals['_TOPICSERVICE']._serialized_end=2191
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/backup.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/mdb/elasticsearch/v1/backup.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x88\x02\n\x06\x42\x61\x63kup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x19\n\x11source_cluster_id\x18\x03 \x01(\t\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x07indices\x18\x06 \x03(\tB\t\x82\xc8\x31\x05<=100\x12\x1d\n\x15\x65lasticsearch_version\x18\x07 \x01(\t\x12\x12\n\nsize_bytes\x18\x08 \x01(\x03\x12\x15\n\rindices_total\x18\t \x01(\x03\x42|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.backup_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _BACKUP.fields_by_name['indices']._options = None
  _BACKUP.fields_by_name['indices']._serialized_options = b'\202\3101\005<=100'
  _globals['_BACKUP']._serialized_start=150
  _globals['_BACKUP']._serialized_end=414
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/runs/run.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from yandex.cloud.ai.assistants.v1 import common_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_common__pb2
from yandex.cloud.ai.assistants.v1.threads import message_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/ai/assistants/v1/runs/run.proto\x12\"yandex.cloud.ai.assistants.v1.runs\x1a#yandex/cloud/ai/common/common.proto\x1a*yandex/cloud/ai/assistants/v1/common.proto\x1a\x33yandex/cloud/ai/assistants/v1/threads/message.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa7\x04\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x61ssistant_id\x18\x02 \x01(\t\x12\x11\n\tthread_id\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.ai.assistants.v1.runs.Run.LabelsEntry\x12;\n\x05state\x18\x07 \x01(\x0b\x32,.yandex.cloud.ai.assistants.v1.runs.RunState\x12?\n\x05usage\x18\x08 \x01(\x0b\x32\x30.yandex.cloud.ai.assistants.v1.runs.ContentUsage\x12`\n custom_prompt_truncation_options\x18\t \x01(\x0b\x32\x36.yandex.cloud.ai.assistants.v1.PromptTruncationOptions\x12S\n\x19\x63ustom_completion_options\x18\n \x01(\x0b\x32\x30.yandex.cloud.ai.assistants.v1.CompletionOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x02\n\x08RunState\x12\x46\n\x06status\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.ai.assistants.v1.runs.RunState.RunStatus\x12.\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.ai.common.ErrorH\x00\x12K\n\x11\x63ompleted_message\x18\x03 \x01(\x0b\x32..yandex.cloud.ai.assistants.v1.threads.MessageH\x00\"`\n\tRunStatus\x12\x1a\n\x16RUN_STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x42\x0b\n\tStateData\"V\n\x0c\x43ontentUsage\x12\x15\n\rprompt_tokens\x18\x01 \x01(\x03\x12\x19\n\x11\x63ompletion_tokens\x18\x02 \x01(\x03\x12\x14\n\x0ctotal_tokens\x18\x03 \x01(\x03\x42u\n&yandex.cloud.api.ai.assistants.v1.runsZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/runs;runsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.runs.run_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&yandex.cloud.api.ai.assistants.v1.runsZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/runs;runs'
  _RUN_LABELSENTRY._options = None
  _RUN_LABELSENTRY._serialized_options = b'8\001'
  _globals['_RUN']._serialized_start=252
  _globals['_RUN']._serialized_end=803
  _globals['_RUN_LABELSENTRY']._serialized_start=758
  _globals['_RUN_LABELSENTRY']._serialized_end=803
  _globals['_RUNSTATE']._serialized_start=806
  _globals['_RUNSTATE']._serialized_end=1124
  _globals['_RUNSTATE_RUNSTATUS']._serialized_start=1015
  _globals['_RUNSTATE_RUNSTATUS']._serialized_end=1111
  _globals['_CONTENTUSAGE']._serialized_start=1126
  _globals['_CONTENTUSAGE']._serialized_end=1212
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SummarizationFieldType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SummarizationFieldTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SummarizationFieldType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SUMMARIZATION_FIELD_TYPE_UNSPECIFIED: _SummarizationFieldType.ValueType  # 0
    TEXT: _SummarizationFieldType.ValueType  # 1
    TEXT_ARRAY: _SummarizationFieldType.ValueType  # 2

class SummarizationFieldType(_SummarizationFieldType, metaclass=_SummarizationFieldTypeEnumTypeWrapper): ...

SUMMARIZATION_FIELD_TYPE_UNSPECIFIED: SummarizationFieldType.ValueType  # 0
TEXT: SummarizationFieldType.ValueType  # 1
TEXT_ARRAY: SummarizationFieldType.ValueType  # 2
global___SummarizationFieldType = SummarizationFieldType

@typing.final
class Summarization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATEMENTS_FIELD_NUMBER: builtins.int
    @property
    def statements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SummarizationStatement]: ...
    def __init__(
        self,
        *,
        statements: collections.abc.Iterable[global___SummarizationStatement] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["statements", b"statements"]) -> None: ...

global___Summarization = Summarization

@typing.final
class SummarizationStatement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def field(self) -> global___SummarizationField: ...
    @property
    def response(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        field: global___SummarizationField | None = ...,
        response: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field", b"field"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["field", b"field", "response", b"response"]) -> None: ...

global___SummarizationStatement = SummarizationStatement

@typing.final
class SummarizationField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    type: global___SummarizationFieldType.ValueType
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        type: global___SummarizationFieldType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name", "type", b"type"]) -> None: ...

global___SummarizationField = SummarizationField



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Image(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ImageType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ImageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Image._ImageType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IMAGE_TYPE_UNSPECIFIED: Image._ImageType.ValueType  # 0
        JPEG: Image._ImageType.ValueType  # 1
        PNG: Image._ImageType.ValueType  # 2

    class ImageType(_ImageType, metaclass=_ImageTypeEnumTypeWrapper):
        """   type of image"""

    IMAGE_TYPE_UNSPECIFIED: Image.ImageType.ValueType  # 0
    JPEG: Image.ImageType.ValueType  # 1
    PNG: Image.ImageType.ValueType  # 2

    CONTENT_FIELD_NUMBER: builtins.int
    IMAGE_TYPE_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """       bytes with data"""
    image_type: global___Image.ImageType.ValueType
    """   type of data"""
    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
        image_type: global___Image.ImageType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ImageSource", b"ImageSource", "content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ImageSource", b"ImageSource", "content", b"content", "image_type", b"image_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ImageSource", b"ImageSource"]) -> typing.Literal["content"] | None: ...

global___Image = Image



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class S3APIGetObjectResponse(google.protobuf.message.Message):
    """Represents a response of the get object request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ETAG_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    ACCEPT_RANGES_FIELD_NUMBER: builtins.int
    CACHE_CONTROL_FIELD_NUMBER: builtins.int
    CONTENT_DISPOSITION_FIELD_NUMBER: builtins.int
    CONTENT_ENCODING_FIELD_NUMBER: builtins.int
    CONTENT_LANGUAGE_FIELD_NUMBER: builtins.int
    CONTENT_LENGTH_FIELD_NUMBER: builtins.int
    CONTENT_RANGE_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    SERVER_SIDE_ENCRYPTION_FIELD_NUMBER: builtins.int
    SSE_KMS_KEY_ID_FIELD_NUMBER: builtins.int
    OBJECT_LOCK_MODE_FIELD_NUMBER: builtins.int
    OBJECT_LOCK_RETAIN_UNTIL_DATE_FIELD_NUMBER: builtins.int
    OBJECT_LOCK_LEGAL_HOLD_STATUS_FIELD_NUMBER: builtins.int
    etag: builtins.str
    """MD5 hash of the object."""
    request_id: builtins.str
    """Unique request ID."""
    accept_ranges: builtins.str
    """Indicates that a range of bytes was specified in the request."""
    cache_control: builtins.str
    """Specifies caching behavior along the request/reply chain."""
    content_disposition: builtins.str
    """Specifies presentational information for the object."""
    content_encoding: builtins.str
    """Indicates what content encodings have been applied to the object."""
    content_language: builtins.str
    """The language the content is in."""
    content_length: builtins.int
    """Size of the body in bytes."""
    content_range: builtins.str
    """The portion of the object returned in the response."""
    content_type: builtins.str
    """A standard MIME type describing the format of the object data."""
    version_id: builtins.str
    """Version ID of the object."""
    storage_class: builtins.str
    """Provides storage class information of the object."""
    server_side_encryption: builtins.str
    """Encryption algorithm used to encrypt the object."""
    sse_kms_key_id: builtins.str
    """ID of the key KMS."""
    object_lock_mode: builtins.str
    """Type of retention put on the object."""
    object_lock_legal_hold_status: builtins.str
    """Type of legal hold put on the object"""
    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The date and time at which the object is no longer cacheable."""

    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Date and time when the object was last modified."""

    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Object user-defined metadata."""

    @property
    def object_lock_retain_until_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Date and time until which the object is retained"""

    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        request_id: builtins.str = ...,
        accept_ranges: builtins.str = ...,
        cache_control: builtins.str = ...,
        content_disposition: builtins.str = ...,
        content_encoding: builtins.str = ...,
        content_language: builtins.str = ...,
        content_length: builtins.int = ...,
        content_range: builtins.str = ...,
        content_type: builtins.str = ...,
        version_id: builtins.str = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        storage_class: builtins.str = ...,
        server_side_encryption: builtins.str = ...,
        sse_kms_key_id: builtins.str = ...,
        object_lock_mode: builtins.str = ...,
        object_lock_retain_until_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        object_lock_legal_hold_status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at", "last_modified_at", b"last_modified_at", "object_lock_retain_until_date", b"object_lock_retain_until_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["accept_ranges", b"accept_ranges", "cache_control", b"cache_control", "content_disposition", b"content_disposition", "content_encoding", b"content_encoding", "content_language", b"content_language", "content_length", b"content_length", "content_range", b"content_range", "content_type", b"content_type", "etag", b"etag", "expires_at", b"expires_at", "last_modified_at", b"last_modified_at", "metadata", b"metadata", "object_lock_legal_hold_status", b"object_lock_legal_hold_status", "object_lock_mode", b"object_lock_mode", "object_lock_retain_until_date", b"object_lock_retain_until_date", "request_id", b"request_id", "server_side_encryption", b"server_side_encryption", "sse_kms_key_id", b"sse_kms_key_id", "storage_class", b"storage_class", "version_id", b"version_id"]) -> None: ...

global___S3APIGetObjectResponse = S3APIGetObjectResponse

@typing.final
class S3APIPutObjectResponse(google.protobuf.message.Message):
    """Represents a response of the put object request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    etag: builtins.str
    """MD5 hash of the object."""
    request_id: builtins.str
    """Unique request ID."""
    version_id: builtins.str
    """Version ID of the object."""
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        request_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["etag", b"etag", "request_id", b"request_id", "version_id", b"version_id"]) -> None: ...

global___S3APIPutObjectResponse = S3APIPutObjectResponse

@typing.final
class S3APIDeleteObjectResponse(google.protobuf.message.Message):
    """Represents a response of the delete object request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    version_id: builtins.str
    """Version ID of the object."""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["request_id", b"request_id", "version_id", b"version_id"]) -> None: ...

global___S3APIDeleteObjectResponse = S3APIDeleteObjectResponse
